@@ -1,6 +1,6 @@
 package SQL::Interpolate;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 use strict;
 use warnings;
@@ -529,6 +529,12 @@ __END__
 
 SQL::Interpolate - Interpolate Perl variables into SQL statements
 
+=head1 STATUS
+
+This module is not being actively maintained, although there is a fork
+with further updates. See the "Fork" section in L<SQL::Interp> docs for details:
+L<http://search.cpan.org/perldoc?SQL::Interp#Fork>.
+
 =head1 SYNOPSIS
 
   use SQL::Interpolate qw(:all);
